document.addEventListener('DOMContentLoaded', function() {
  // Tracking form functionality
  const trackingForm = document.querySelector('.tracking-form');
  const trackingInput = document.getElementById('tracking-input');
  const trackingResults = document.getElementById('tracking-results');
  
  if (trackingForm) {
    trackingForm.addEventListener('submit', function(e) {
      e.preventDefault();
      const trackingNumber = trackingInput.value.trim();
      
      if (trackingNumber) {
        // Simulate tracking lookup
        simulateTracking(trackingNumber);
      }
    });
  }
  
  function simulateTracking(trackingNumber) {
    // Show loading state
    trackingResults.innerHTML = '<p>Looking up your package...</p>';
    trackingResults.style.display = 'block';
    
    // Simulate API delay
    setTimeout(() => {
      // Generate random status
      const statuses = [
        { status: 'In Transit', location: 'New York, NY', eta: 'Tomorrow by 8pm' },
        { status: 'Out for Delivery', location: 'Your Local Facility', eta: 'Today by 5pm' },
        { status: 'Delivered', location: 'Front Door', eta: 'Delivered at 2:30pm' },
        { status: 'Processing', location: 'Chicago, IL', eta: '3-5 business days' }
      ];
      
      const randomStatus = statuses[Math.floor(Math.random() * statuses.length)];
      
      // Update results
      trackingResults.innerHTML = `
        <h3>Tracking #${trackingNumber}</h3>
        <div class="status-card">
          <p><strong>Status:</strong> ${randomStatus.status}</p>
          <p><strong>Location:</strong> ${randomStatus.location}</p>
          <p><strong>Estimated Delivery:</strong> ${randomStatus.eta}</p>
        </div>
        <div class="status-timeline">
          <div class="timeline-item active">
            <div class="timeline-dot"></div>
            <p>Order Processed</p>
            <p class="timeline-date">${getRandomPastDate(4)}</p>
          </div>
          <div class="timeline-item ${randomStatus.status !== 'Processing' ? 'active' : ''}">
            <div class="timeline-dot"></div>
            <p>Shipped</p>
            <p class="timeline-date">${getRandomPastDate(3)}</p>
          </div>
          <div class="timeline-item ${['In Transit', 'Out for Delivery', 'Delivered'].includes(randomStatus.status) ? 'active' : ''}">
            <div class="timeline-dot"></div>
            <p>In Transit</p>
            <p class="timeline-date">${getRandomPastDate(2)}</p>
          </div>
          <div class="timeline-item ${['Out for Delivery', 'Delivered'].includes(randomStatus.status) ? 'active' : ''}">
            <div class="timeline-dot"></div>
            <p>Out for Delivery</p>
            <p class="timeline-date">${randomStatus.status === 'Delivered' ? getRandomPastDate(1) : 'Today'}</p>
          </div>
          ${randomStatus.status === 'Delivered' ? `
          <div class="timeline-item active">
            <div class="timeline-dot"></div>
            <p>Delivered</p>
            <p class="timeline-date">Today</p>
          </div>
          ` : ''}
        </div>
      `;
    }, 1500);
  }
  
  function getRandomPastDate(daysAgo) {
    const date = new Date();
    date.setDate(date.getDate() - daysAgo + Math.floor(Math.random() * 2));
    return date.toLocaleDateString('en-US', { month: 'short', day: 'numeric' });
  }
  
  // Smooth scrolling for anchor links
  document.querySelectorAll('a[href^="#"]').forEach(anchor => {
    anchor.addEventListener('click', function(e) {
      e.preventDefault();
      
      const targetId = this.getAttribute('href');
      if (targetId === '#') return;
      
      const targetElement = document.querySelector(targetId);
      if (targetElement) {
        window.scrollTo({
          top: targetElement.offsetTop - 80,
          behavior: 'smooth'
        });
      }
    });
  });
  
  // Mobile menu toggle (would be added if we had a mobile menu)
  // Form validation could be added here for the contact form
});